from django.contrib.auth import get_user_model
from rest_framework import permissions, viewsets

from help.models import HelpUser
from help.serializers import HelpUserSerializer, UserSerializer

User = get_user_model()


class UserViewSet(viewsets.ReadOnlyModelViewSet):
    """
    API endpoint that allows users to be viewed or edited.

    """

    queryset = User.objects.all().order_by("-username")
    serializer_class = UserSerializer
    permission_classes = [permissions.IsAdminUser]


class HelpUserViewSet(viewsets.ModelViewSet):
    """
    API endpoint that allows user help profile to be viewed or edited.

    """

    queryset = HelpUser.objects.all().order_by("-user__username")
    serializer_class = HelpUserSerializer
    permission_classes = [permissions.IsAdminUser]
